@@ -2,7 +2,7 @@ context('reprs of html widgets and tags')
 
 test_that('A basic tag works', {
 	r <- repr_html(htmltools::div())
-	expect_identical(r, sprintf(repr:::HTML_SKELETON, '', '<div></div>'))
+	expect_id_text(r, sprintf(repr:::HTML_SKELETON, '', '<div></div>'))
 })
 
 test_that('A basic widget works', {
@@ -18,7 +18,7 @@ test_that('Dependencies work', {
 	skip_if_not_installed('htmlwidgets')
 	
 	r <- repr_html(stringr::str_view('xy', 'y'))
-	expect_match(r, '<script src="data:application/javascript', fixed = TRUE, all = FALSE)
+	expect_match(r, '<script title="htmlwidgets" src="data:application/javascript', fixed = TRUE, all = FALSE)
 })
 
 test_that('The dependency manager works', {
@@ -35,3 +35,12 @@ test_that('The dependency manager works', {
 	r <- repr_html(stringr::str_view('xy', 'y'))
 	expect_match(r, '<meta charset="utf-8">\n\t\t\n', fixed = TRUE, all = FALSE)  #no deps here
 })
+
+test_that('Leaflet HTML and deps can be represented', {
+	skip_if_not_installed('leaflet')
+
+	leaf <- leaflet::addTiles(leaflet::leaflet())
+
+	r <- repr_html(leaf)
+	expect_match(r, '<script title="htmlwidgets" src="data:')
+})
